
/* This modified version of sample.c contains a function to help
 * automate the process of merging a series of files.  You must have 
 * Codewright version 4.0 make use of this function.
 *
 * Some setup is required.  The function expects to find a [Merge]
 * section in your CWRIGHT.INI file.  In it, you can specify a 
 * directory where your base files can be found (MergeBaseDir), and 
 * another where one of the revisions to the base file is found 
 * (MergeRevDir).  The current buffer is assumed to be the other 
 * revision.  The [Merge] section of your CWRIGHT.INI file might 
 * look like this:
 *
 * [Merge]
 * MergeBaseDir=d:\\cw30g\\orig
 * MergeRevDir=d:\\cw30g\\mine
 *
 * Note that backspaces are doubled because the directory string can 
 * contain any of the excape sequences documented for the 
 * ExtExpandTemplate function.
 * 
 * The function specifies that the output filename is the same as the 
 * current buffer's name, except that it is given the extension .MRG.
 * the resulting file is loaded for viewing.
 */

#include <windows.h>
#include "exports.h"
#include "cwstart.h"


LIBMAIN


/* When this DLL is first loaded either by LibPreLoad() or LibAutoLoad(),
 * the function _init() is invoked.  Within this function, all DLL specific
 * initialization should be performed such as:
 *
 *         - Defining any module global keystrokes or keymaps to be used
 *         - Exporting any functions to be accessed through LibFunctionExec()
 *         - Autoloading any other DLLs.
 *
 */
void DLL 
_init()
{
	/* Place all 'LibExport' calls here.
	 */
	// i.e.
	LibExport( "int AutoMerge" );
}


BOOL DLL AutoMerge( void )
{
	LPSTR MergeCommand, MergeCmdStr, OutputFilename, CurExt;
	char RevDir[80], BaseDir[80];
	int Result;
	
	GetPrivateProfileString( "Merge", "MergeRevDir", "..\\\\mine", RevDir, 
					80, ConfigQFilename() );
				
	GetPrivateProfileString( "Merge", "MergeBaseDir", "..\\\\orig", BaseDir, 
					80, ConfigQFilename() );
	
	MergeCommand = StrNew( "Merge " );
	MergeCommand = StrAppend( MergeCommand, BaseDir);
	MergeCommand = StrAppend( MergeCommand, "\\\\%-r%-e 0 '' ");
	MergeCommand = StrAppend( MergeCommand, RevDir);
	MergeCommand = StrAppend( MergeCommand, "\\\\%-r%-e 0 '' %-b%-e 1 '' %-b.mrg '------'");

	MergeCmdStr = ExtExtractTemplate( MergeCommand );
	Result = (int)LibFunctionExec( MergeCmdStr );
	
	if ( Result )
	{ 
		if (Result > 0)
			MsgPrintf(3, "Merge complete.  %d conflicts.", Result);
		else
		{
			MsgPrintf(3, "Merge err: %d %s", Result, MergeCmdStr);
			StrFree( MergeCommand );
			return FALSE;
		}
	}
	else
		MsgMessage("Merge complete.  No conflicts found.");

	OutputFilename = TransformFilename(BufQFilename(),"%b.mrg");
	CurExt = TransformFilename(BufQFilename(), "%e" );
	ExtAlias(".mrg", CurExt);
	BufEditFile(OutputFilename);

	//MsgMessage( ExtExtractTemplate( MergeCommand ) );
	
	StrFree( MergeCommand );
	StrFree( OutputFilename );
	StrFree( CurExt );

	return(TRUE);
}